==> alibabacloud_rds20140815_py2-1.6.0.tar.gz: alibabacloud_rds20140815_py2-1.6.0/ChangeLog.md <==
2023-09-14 Version: 1.5.0
- Generated python2 2014-08-15 for Rds.

2023-08-08 Version: 1.4.4
- Generated python2 2014-08-15 for Rds.

2023-08-06 Version: 1.4.3
- Generated python2 2014-08-15 for Rds.

2023-08-05 Version: 1.4.2
- Generated python2 2014-08-15 for Rds.

2023-08-04 Version: 1.4.1
- Generated python2 2014-08-15 for Rds.

2023-07-31 Version: 1.4.0
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-30 Version: 1.3.9
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-29 Version: 1.3.8
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-28 Version: 1.3.7
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-27 Version: 1.3.6
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-25 Version: 1.3.5
- Add error code.
- Support System param.

2023-07-24 Version: 1.3.4
- Add error code.
- Add error code for CreateDBNodes.

2023-07-23 Version: 1.3.3
- Fix 500 for CreateOrder.
- Support sts.

2023-07-22 Version: 1.3.2
- Fix 500 for CreateOrder.
- Support sts.

2023-07-21 Version: 1.3.1
- Fix 500 for CreateOrder.
- Support sts.

2023-07-19 Version: 1.3.0
- Add openapis for whitelist template.

2023-07-18 Version: 1.2.9
- Supported RDS PostgreSQL manage extensions.

2023-07-17 Version: 1.2.8
- Add TimeOut.

2023-07-16 Version: 1.2.7
- Add error code.

2023-07-15 Version: 1.2.6
- Add error code.

2023-07-13 Version: 1.2.5
- Support change instance config event for rds.
- Add NodeId param for restart slave.

2023-07-12 Version: 1.2.4
- Add error coede.
- Fix bugs for 500.

2023-07-11 Version: 1.2.3
- Fixed 500 for interface.

2023-07-10 Version: 1.2.2
- Fixed 500 for interface.

2023-07-10 Version: 1.2.1
- Add DescribeClassDetails Api.

2023-07-09 Version: 1.2.0
- Add AutoUseCoupon field.
- Api Offline.

2023-07-08 Version: 1.1.9
- Add AutoUseCoupon field.
- Api Offline.

2023-07-07 Version: 1.1.8
- Add AutoUseCoupon field.
- Api Offline.

2023-07-06 Version: 1.1.7
- Add AutoUseCoupon field.
- Api Offline.

2023-07-05 Version: 1.1.6
- Add AutoUseCoupon field.
- Api Offline.

2023-07-04 Version: 1.1.5
- Fix bugs for  DescribeDedicatedHosts.
- Fixed bugs add ERRORCODE.
- Added serverless config to support serverless price query.

2023-07-04 Version: 1.1.4
- ModifyBackupPolicy API support parameter BackupPriority.
- DescribeBackupPolicy API add return parameters: BackupPriority and SupportModifyBackupPriority.

2023-07-03 Version: 1.1.3
- Fix bugs for  DescribeDedicatedHosts.
- Fixed bugs add ERRORCODE.
- Added serverless config to support serverless price query.

2023-07-02 Version: 1.1.2
- Fixed bugs for lack of regionId.
- Fix error code.

2023-07-01 Version: 1.1.1
- Fixed bugs for lack of regionId.
- Fix error code.

2023-06-30 Version: 1.1.0
- Fixed bugs for lack of regionId.
- Fix error code.

2023-06-30 Version: 1.0.9
- ModifyBackupPolicy API support parameter BackupPriority.
- DescribeBackupPolicy API add return parameters: BackupPriority and SupportModifyBackupPriority.

2023-06-29 Version: 1.0.8
- Support More Open Api.

2023-06-26 Version: 1.0.7
- Support More Open Api.

2023-06-15 Version: 1.0.6
- Support More Open Api.

2023-03-27 Version: 1.0.5
- Support More Open Api.

2023-02-21 Version: 1.0.4
- Support More Open Api.

2021-09-16 Version: 1.0.3
- AMP Version Change.

2021-07-28 Version: 1.0.2
- AMP Version Change.

2021-07-05 Version: 1.0.1
- AMP Version Change.

2021-04-29 Version: 1.0.0
- Update AMP API.

==> alibabacloud_rds20140815_py2-2.0.3.tar.gz: alibabacloud_rds20140815_py2-2.0.3/ChangeLog.md <==
2024-01-05 Version: 2.0.2
- Generated python2 2014-08-15 for Rds.

2023-12-20 Version: 2.0.1
- Generated python2 2014-08-15 for Rds.

2023-12-15 Version: 2.0.0
- Generated python2 2014-08-15 for Rds.

2023-12-07 Version: 1.8.1
- Generated python2 2014-08-15 for Rds.

2023-12-06 Version: 1.8.0
- Generated python2 2014-08-15 for Rds.

2023-11-23 Version: 1.7.5
- Generated python2 2014-08-15 for Rds.

2023-11-23 Version: 1.7.4
- Generated python2 2014-08-15 for Rds.

2023-11-21 Version: 1.7.3
- Generated python2 2014-08-15 for Rds.

2023-11-15 Version: 1.7.2
- Generated python2 2014-08-15 for Rds.

2023-11-10 Version: 1.7.1
- Generated python2 2014-08-15 for Rds.

2023-11-07 Version: 1.7.0
- Generated python2 2014-08-15 for Rds.

2023-10-21 Version: 1.6.0
- Generated python2 2014-08-15 for Rds.

2023-09-14 Version: 1.5.0
- Generated python2 2014-08-15 for Rds.

2023-08-08 Version: 1.4.4
- Generated python2 2014-08-15 for Rds.

2023-08-06 Version: 1.4.3
- Generated python2 2014-08-15 for Rds.

2023-08-05 Version: 1.4.2
- Generated python2 2014-08-15 for Rds.

2023-08-04 Version: 1.4.1
- Generated python2 2014-08-15 for Rds.

2023-07-31 Version: 1.4.0
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-30 Version: 1.3.9
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-29 Version: 1.3.8
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-28 Version: 1.3.7
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-27 Version: 1.3.6
- Fix bug ram.
- Add minor version error.
- Support to select the minor version of the kernel when the modify instance error reports that the kernel version does not support it.

2023-07-25 Version: 1.3.5
- Add error code.
- Support System param.

2023-07-24 Version: 1.3.4
- Add error code.
- Add error code for CreateDBNodes.

2023-07-23 Version: 1.3.3
- Fix 500 for CreateOrder.
- Support sts.

2023-07-22 Version: 1.3.2
- Fix 500 for CreateOrder.
- Support sts.

2023-07-21 Version: 1.3.1
- Fix 500 for CreateOrder.
- Support sts.

2023-07-19 Version: 1.3.0
- Add openapis for whitelist template.

2023-07-18 Version: 1.2.9
- Supported RDS PostgreSQL manage extensions.

2023-07-17 Version: 1.2.8
- Add TimeOut.

2023-07-16 Version: 1.2.7
- Add error code.

2023-07-15 Version: 1.2.6
- Add error code.

2023-07-13 Version: 1.2.5
- Support change instance config event for rds.
- Add NodeId param for restart slave.

2023-07-12 Version: 1.2.4
- Add error coede.
- Fix bugs for 500.

2023-07-11 Version: 1.2.3
- Fixed 500 for interface.

2023-07-10 Version: 1.2.2
- Fixed 500 for interface.

2023-07-10 Version: 1.2.1
- Add DescribeClassDetails Api.

2023-07-09 Version: 1.2.0
- Add AutoUseCoupon field.
- Api Offline.

2023-07-08 Version: 1.1.9
- Add AutoUseCoupon field.
- Api Offline.

2023-07-07 Version: 1.1.8
- Add AutoUseCoupon field.
- Api Offline.

2023-07-06 Version: 1.1.7
- Add AutoUseCoupon field.
- Api Offline.

2023-07-05 Version: 1.1.6
- Add AutoUseCoupon field.
- Api Offline.

2023-07-04 Version: 1.1.5
- Fix bugs for  DescribeDedicatedHosts.
- Fixed bugs add ERRORCODE.
- Added serverless config to support serverless price query.

2023-07-04 Version: 1.1.4
- ModifyBackupPolicy API support parameter BackupPriority.
- DescribeBackupPolicy API add return parameters: BackupPriority and SupportModifyBackupPriority.

2023-07-03 Version: 1.1.3
- Fix bugs for  DescribeDedicatedHosts.
- Fixed bugs add ERRORCODE.
- Added serverless config to support serverless price query.

2023-07-02 Version: 1.1.2
- Fixed bugs for lack of regionId.
- Fix error code.

2023-07-01 Version: 1.1.1
- Fixed bugs for lack of regionId.
- Fix error code.

2023-06-30 Version: 1.1.0
- Fixed bugs for lack of regionId.
- Fix error code.

2023-06-30 Version: 1.0.9
- ModifyBackupPolicy API support parameter BackupPriority.
- DescribeBackupPolicy API add return parameters: BackupPriority and SupportModifyBackupPriority.

2023-06-29 Version: 1.0.8
- Support More Open Api.

2023-06-26 Version: 1.0.7
- Support More Open Api.

2023-06-15 Version: 1.0.6
- Support More Open Api.

2023-03-27 Version: 1.0.5
- Support More Open Api.

2023-02-21 Version: 1.0.4
- Support More Open Api.

2021-09-16 Version: 1.0.3
- AMP Version Change.

2021-07-28 Version: 1.0.2
- AMP Version Change.

2021-07-05 Version: 1.0.1
- AMP Version Change.

2021-04-29 Version: 1.0.0
- Update AMP API.
